@@ -5,13 +5,13 @@
 
 package XML::Compile::Translate::Template;
 use vars '$VERSION';
-$VERSION = '1.22';
+$VERSION = '1.23';
 
 use base 'XML::Compile::Translate';
 
 use strict;
 use warnings;
-no warnings 'once';
+no warnings 'once', 'recursion';
 
 use XML::Compile::Util
   qw/odd_elements even_elements SCHEMA2001i pack_type unpack_type/;
@@ -391,7 +391,8 @@ sub makeFacets
         : $k eq 'minInclusive' ? "value >= $v"
         : $k eq 'minExclusive' ? "value >  $v"
         : $k eq 'fractionDigits' ? "faction digits is $v"
-        : "restriction $k = $v";
+        : $k eq 'whiteSpace'   ? "white-space $v"
+        : "restriction? $k = $v";
     }
 
     my %facet = (facets => \@comment, $st->());
@@ -808,9 +809,8 @@ sub toXML($$%)
 
     my $header = $doc->createComment( <<_HEADER . '    ' );
  BE WARNED: in most cases, the example below cannot be used without
-    -- interpretation.  The comments will guide you.
-    -- Produced by $pkg version $VERSION
-    --          on $now
+  interpretation. The comments will guide you.
+  Produced by $pkg version $VERSION on $now
 _HEADER
 
     unless($args{skip_header})
